darkhistory.spec.spectools.engloss_rebin_fast — DarkHistory documentation

# darkhistory.spec.spectools.engloss_rebin_fast

`darkhistory.spec.spectools.` `engloss_rebin_fast`(in_eng, eng, grid_vals, final_eng)

  Fast energy loss rebin.

  Parameters: | in_eng : ndarray Injection energies (first dimension of grid_vals) eng : ndarray Energy loss abscissa (second dimension of grid_vals) grid_vals : 2D ndarray Number of particles with the given energy in eng. final_eng : ndarray The final energy abscissa to bin into.
  Returns: | Spectra The final rebinned spectra.

#### Previous topic

darkhistory.spec.spectools.discretize

#### Next topic

darkhistory.spec.spectools.get_bin_bound

### This Page

Show Source